@@ -14,35 +14,54 @@ signeture 'Data::Util' => \&install_subroutine;
 
 
 my $pkg  = do{ package Foo; __PACKAGE__ };
-my $foo = \&foo;
-my $bar = \&bar;
 
-sub foo{}
-sub bar{}
+sub foo{ 42 }
+
 
 print "Installing a subroutine:\n";
 cmpthese timethese -1 => {
 	installer => sub{
 		no warnings 'redefine';
-		install_subroutine($pkg, foo => $foo);
+		install_subroutine($pkg, foo => \&foo);
 	},
 	direct => sub{
 		no warnings 'redefine';
 		no strict 'refs';
-		*{$pkg . '::foo'} = $foo;
+		*{$pkg . '::foo'} = \&foo;
 	},
 };
 
-print "\nInstalling two subroutines:\n";
+print "\nInstalling 2 subroutines:\n";
 cmpthese timethese -1 => {
 	installer => sub{
 		no warnings 'redefine';
-		install_subroutine($pkg, foo => $foo, bar => $bar);
+		install_subroutine($pkg, foo => \&foo, bar => \&foo);
 	},
 	direct => sub{
 		no warnings 'redefine';
 		no strict 'refs';
-		*{$pkg . '::foo'} = $foo;
-		*{$pkg . '::bar'} = $bar;
+		*{$pkg . '::foo'} = \&foo;
+		*{$pkg . '::bar'} = \&foo;
+	},
+};
+
+print "\nInstalling 4 subroutines:\n";
+cmpthese timethese -1 => {
+	installer => sub{
+		no warnings 'redefine';
+		install_subroutine($pkg,
+			foo => \&foo,
+			bar => \&foo,
+			baz => \&foo,
+			baz => \&foo,
+		);
+	},
+	direct => sub{
+		no warnings 'redefine';
+		no strict 'refs';
+		*{$pkg . '::foo'} = \&foo;
+		*{$pkg . '::bar'} = \&foo;
+		*{$pkg . '::baz'} = \&foo;
+		*{$pkg . '::bax'} = \&foo;
 	},
 };
